summaryrefslogtreecommitdiff
path: root/gnu/packages/python-xyz.scm
diff options
context:
space:
mode:
authorTobias Geerinckx-Rice <me@tobias.gr>2022-12-04 01:00:52 +0100
committerTobias Geerinckx-Rice <me@tobias.gr>2022-12-11 01:00:00 +0100
commit8fe6d3e8446944294856950ef192cac83e03e58b (patch)
tree9f19f2d8e7e8ea7f1a6f6d432961e8197cd45955 /gnu/packages/python-xyz.scm
parentb5f3a1b84e2bd3e03452c57ef2785a8f98124361 (diff)
downloadguix-patches-8fe6d3e8446944294856950ef192cac83e03e58b.tar
guix-patches-8fe6d3e8446944294856950ef192cac83e03e58b.tar.gz
gnu: yajl: Drop custom ‘lib-’ prefix.
* gnu/packages/web.scm (yajl): New variable, renamed from… (libyajl): …this one, which is now a DEPRECATED-PACKAGE alias of yajl. Adjust all users.
Diffstat (limited to 'gnu/packages/python-xyz.scm')
-rw-r--r--gnu/packages/python-xyz.scm4
1 files changed, 2 insertions, 2 deletions
diff --git a/gnu/packages/python-xyz.scm b/gnu/packages/python-xyz.scm
index 8591423116..9629012a80 100644
--- a/gnu/packages/python-xyz.scm
+++ b/gnu/packages/python-xyz.scm
@@ -29784,9 +29784,9 @@ simple mock/record and a complete capture/replay framework.")
(when tests?
(invoke "pytest" "-vv")))))))
(inputs
;; libyajl is optional, but compiling with it makes faster
;; backends available to ijson:
- (list libyajl))
+ (list yajl))
(native-inputs
(list python-pytest))
(build-system python-build-system)
@@ -29784,9 +29784,9 @@ simple mock/record and a complete capture/replay framework.")
(invoke "pytest" "-vv")))))))
(inputs
- ;; libyajl is optional, but compiling with it makes faster
+ ;; yajl is optional, but compiling with it makes faster
;; backends available to ijson: